==> nextcloud-20.0.7-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_sharing/l10n/zh_HK.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with you" : "與您分享",
    "Nothing shared with you yet" : "目前沒有任何與您分享的內容",
    "Files and folders others share with you will show up here" : "與您分享的檔案與資料夾將會顯示在這裡",
    "Shared with others" : "與其他人分享",
    "Nothing shared yet" : "目前沒有分享內容",
    "Files and folders you share will show up here" : "您分享的檔案與資料夾將會顯示在這裡",
    "Shared by link" : "由連結分享",
    "No shared links" : "沒有已分享的連結",
    "Files and folders you share by link will show up here" : "您分享的檔案與資料夾連結將會顯示在這裡",
    "Deleted shares" : "移除分享",
    "No deleted shares" : "沒有移除的分享",
    "Shares you deleted will show up here" : "您刪除的分享會在此顯示",
    "Pending shares" : "等待分享",
    "No pending shares" : "沒有待處理的分享",
    "Shares you have received but not confirmed will show up here" : "您收到但尚未確認的分享將會在此顯示",
    "Shares" : "分享",
    "No shares" : "無分享",
    "Shares will show up here" : "分享將會在此顯示",
    "Restore" : "回復",
    "Restore share" : "還原分享",
    "Something happened. Unable to restore the share." : "出了些狀況，無法還原分享。",
    "Accept share" : "接受分享",
    "Something happened. Unable to accept the share." : "好像有東西出錯了。無法接受分享。",
    "Reject share" : "拒絕分享",
    "Something happened. Unable to reject the share." : "好像有東西出錯了。無法拒絕分享。",
    "Waiting…" : "正在等待……",
    "error" : "錯誤",
    "finished" : "已結束",
    "This will stop your current uploads." : "這會終止目前任何的上傳。",
    "Move or copy" : "移動或複製",
    "Download" : "下載",
    "Delete" : "移除",
    "You can upload into this folder" : "你可以上傳內容到此資料夾",
    "Terms of service" : "服務條款",
    "No compatible server found at {remote}" : "沒有在 {remote} 找到相容的伺服器",
    "Invalid server URL" : "無效的伺服器 URL",
    "Failed to add the public link to your Nextcloud" : "無法將公開連結加入您的 Nextcloud",
    "No expiration date set" : "未指定到期日",
    "Shared by" : "分享自",
    "File shares" : "檔案分享",
    "Downloaded via public link" : "透過公用連結下載",
    "Downloaded by {email}" : "{email} 已下載",
    "{file} downloaded via public link" : "{file} 已透過公用連結下載",
    "{email} downloaded {file}" : "{email} 已下載 {file}",
    "Shared with group {group}" : "與群組 {group} 分享",
    "Removed share for group {group}" : "移除與群組 {group} 分享",
    "{actor} shared with group {group}" : "{actor} 分享給群組 {group}",
    "{actor} removed share for group {group}" : "{actor} 移除了與群組 {group} 的分享",
    "Share for group {group} expired" : "群組 {group} 的分享已過期",
    "You shared {file} with group {group}" : "你分享了 {file} 給群組 {group}",
    "You removed group {group} from {file}" : "你將群組 {group} 從 {file} 移除",
    "{actor} shared {file} with group {group}" : "{actor} 分享 {file} 給群組 {group}",
    "{actor} removed group {group} from {file}" : "{actor} 將群組 {group} 從 {file} 移除",
    "Share for file {file} with group {group} expired" : "與群組 {group} 分享的檔案 {file} 已過期",
    "Shared as public link" : "藉由公用連結分享",
    "Removed public link" : "刪除公開連結",
    "Public link expired" : "公開連結已過期",
    "{actor} shared as public link" : "{actor} 透過公開連結分享",
    "{actor} removed public link" : "{actor} 移除公開連結分享",
    "Public link of {actor} expired" : "{actor} 的公開連結過期了",
    "You shared {file} as public link" : "你藉由公用連結分享了 {file}",
    "You removed public link for {file}" : "您刪除了 {file} 的公開分享連結",
    "Public link expired for {file}" : "{file} 的公開連結已過期",
    "{actor} shared {file} as public link" : "{actor} 透過公開連結分享 {file}",
    "{actor} removed public link for {file}" : "{actor} 移除 {file} 的公開連結分享",
    "Public link of {actor} for {file} expired" : "{actor} 公開分享 {file} 的連結過期了",
    "{user} accepted the remote share" : "{user} 接受了遠端分享",
    "{user} declined the remote share" : "{user} 拒絕了遠端分享",
    "You received a new remote share {file} from {user}" : "您收到了一個遠端分享 {file} 來自於 {user}",
    "{user} accepted the remote share of {file}" : "{user} 接受了檔案 {file} 的遠端分享",
    "{user} declined the remote share of {file}" : "{user} 拒絕了檔案 {file} 的遠端分享",
    "{user} unshared {file} from you" : "{user} 取消與你分享檔案 {file}",
    "Shared with {user}" : "與 {user} 分享",
    "Removed share for {user}" : "移除對 {user} 的分享",
    "You removed yourself" : "您自己移除",
    "{actor} removed themselves" : "{actor} 已將自己移除",
    "{actor} shared with {user}" : "{actor} 分享給 {user}",
    "{actor} removed share for {user}" : "{actor} 移除了對 {user} 的分享",
    "Shared by {actor}" : "由 {actor} 分享",
    "{actor} removed share" : "{actor} 移除了分享",
    "Share for {user} expired" : "{user} 的分享已過期",
    "Share expired" : "分享已過期",
    "You shared {file} with {user}" : "你與 {user} 分享了 {file}",
    "You removed {user} from {file}" : "你將 {user} 從 {file} 移除",
    "You removed yourself from {file}" : "您已將自己從 {file} 移除",
    "{actor} removed themselves from {file}" : "{actor} 從 {file} 移除了自己",
    "{actor} shared {file} with {user}" : "{actor} 分享了 {file} 給 {user}",
    "{actor} removed {user} from {file}" : "{actor} 移除 {user} 從 {file}",
    "{actor} shared {file} with you" : "{actor} 與你分享了 {file}",
    "{actor} removed you from the share named {file}" : "{actor} 將您從名為 {file} 的分享中移除了",
    "Share for file {file} with {user} expired" : "與 {user} 分享的檔案 {file} 已過期",
    "Share for file {file} expired" : "檔案 {file} 的分享已過期",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "email或公開連結分享的檔案與資料夾已被 <strong>下載</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "檔案或目錄已被 <strong>其他伺服器</strong> 分享",
    "Files" : "檔案",
    "A file or folder has been <strong>shared</strong>" : "檔案或目錄已被 <strong>分享</strong>",
    "Shared link" : "已分享的連結",
    "Wrong share ID, share doesn't exist" : "錯誤的分享 ID ，分享不存在",
    "Could not delete share" : "無法刪除分享",
    "Please specify a file or folder path" : "請指定檔案或資料夾路徑",
    "Wrong path, file/folder doesn't exist" : "錯誤的路徑，該檔案或資料夾不存在",
    "Could not create share" : "無法建立分享",
    "invalid permissions" : "無效的權限",
    "Please specify a valid user" : "請選擇一個有效的使用者",
    "Group sharing is disabled by the administrator" : "群組分享已被管理員停用",
    "Please specify a valid group" : "請指定一個有效的群組",
    "Public link sharing is disabled by the administrator" : "公開連結分享已被管理員停用",
    "Public upload disabled by the administrator" : "公開上傳已被管理員停用",
    "Public upload is only possible for publicly shared folders" : "只有公開分享的資料夾可以接受公開上傳",
    "Sharing %s sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "因為未啟用 Nextcloud Talk，因此透過 Nextcloud Talk 傳送密碼分享 %s 失敗",
    "Invalid date, date format must be YYYY-MM-DD" : "無效的日期，需為 YYYY-MM-DD 格式",
    "Sharing %1$s failed because the back end does not allow shares from type %2$s" : "分享 %1$s 失敗，因為後端不允許來自 %2$s 類型的分享",
    "You cannot share to a Circle if the app is not enabled" : "當應用未被啟用，你無法分享到circle。",
    "Please specify a valid circle" : "請指定一個有效的circle",
    "Sharing %s failed because the back end does not support room shares" : "分享 %s 失敗，因為後端不支援聊天室分享",
    "Unknown share type" : "未知的分享類型",
    "Not a directory" : "這不是一個資料夾",
    "Could not lock node" : "無法鎖定節點",
    "Could not lock path" : "無法鎖定路徑",
    "Wrong or no update parameter given" : "更新參數不正確或未提供",
    "Can't change permissions for public share links" : "無法由公開分享的連結變更權限",
    "Sharing sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "因為未啟用 Nextcloud Talk，因此透過 Nextcloud Talk 傳送密碼分享失敗",
    "shared by %s" : "分享自 %s",
    "Download all files" : "下載所有檔案",
    "Direct link" : "直接連結",
    "Add to your Nextcloud" : "加入到您的 Nextcloud",
    "Share API is disabled" : "分享 API 已停用",
    "File sharing" : "檔案分享",
    "Share will expire tomorrow" : "分享將於明天到期",
    "One or more of your shares will expire tomorrow" : "您的一個或多個分享將於明天到期",
    "Your share of {node} will expire tomorrow" : "您 {node} 的分享將於明天到期",
    "You received {share} as a share by {user}" : "您收到 {user} 的分享 {share}",
    "Accept" : "接受",
    "Reject" : "拒絕",
    "Sharing" : "分享",
    "Accept user and group shares by default" : "默認接受用戶和群組共享",
    "Allow editing" : "允許編輯",
    "Allow creating" : "允許創建",
    "Allow deleting" : "允許刪除",
    "Allow resharing" : "允許轉貼分享",
    "Expiration date enforced" : "已設定到期日",
    "Set expiration date" : "設定到期日",
    "Enter a date" : "輸入日期",
    "Note to recipient" : "給接收者的訊息",
    "Unshare" : "撤回分享",
    "group" : "群組",
    "conversation" : "交談",
    "remote" : "遠端",
    "remote group" : "遠端群組",
    "guest" : "訪客",
    "Shared with the group {user} by {owner}" : "由 {owner} 分享予群組 {user}",
    "Shared with the conversation {user} by {owner}" : "{owner}與{user}共享",
    "Shared with {user} by {owner}" : "{user}與{owner}共享",
    "Added by {initiator}" : "由{initiator}添加",
    "Via “{folder}”" : "透過 “{folder}”",
    "Internal link" : "內部鏈接",
    "Link copied" : "連結已複製",
    "Copy to clipboard" : "複製到剪貼簿",
    "Only works for users with access to this folder" : "只對可以存取此資料夾的使用者生效",
    "Password protection (enforced)" : "密碼保護（強制）",
    "Password protection" : "密碼保護",
    "Enter a password" : "輸入密碼",
    "Expiration date (enforced)" : "屆滿日期（強制）",
    "Create share" : "創建分享",
    "Cancel" : "取消",
    "Share label" : "分享標籤",
    "Read only" : "唯讀",
    "Allow upload and editing" : "允許上傳及編輯",
    "File drop (upload only)" : "拖曳檔案(僅供上傳)",
    "Hide download" : "隱藏下載",
    "Password protect" : "密碼防護",
    "Add another link" : "加入另一個連結",
    "{shareWith} by {initiator}" : "{initiator} 分享了 {shareWith}",
    "Shared via link by {initiator}" : "由 {initiator} 透過鏈接分享",
    "Share link ({label})" : "分享鏈接 ({label})",
    "Share link" : "分享連結",
    "Resharing is not allowed" : "不允許重新分享",
    "Name or email …" : "名字或電郵地址",
    "Name, email, or Federated Cloud ID …" : "名字，電郵地址或 Federated Cloud ID …",
    "Searching …" : "搜尋中 …",
    "Search globally" : "全域搜尋",
    "Shared" : "已分享",
    "Share" : "分享",
    "Shared with" : "分享給",
    "Shared with you and the group {group} by {owner}" : "由 {owner} 分享給您和 {group}群組",
    "Shared with you and {circle} by {owner}" : "{owner} 分享給您和 {circle}",
    "Shared with you and the conversation {conversation} by {owner}" : "{owner} 分享給您和 {conversation} 對話",
    "Shared with you in a conversation by {owner}" : "{owner} 在對話中分享給您",
    "Shared with you by {owner}" : "{owner} 已經和您分享",
    "No entries found in this folder" : "在此資料夾中沒有任何項目",
    "Name" : "名稱",
    "Share time" : "分享時間",
    "Expiration date" : "到期日",
    "Sorry, this link doesn’t seem to work anymore." : "抱歉，此連結已經失效",
    "Reasons might be:" : "可能的原因：",
    "the item was removed" : "項目已經移除",
    "the link expired" : "連結過期",
    "sharing is disabled" : "分享功能已停用",
    "For more info, please ask the person who sent this link." : "請詢問告訴您此連結的人以瞭解更多",
    "Toggle grid view" : "切換網格檢視",
    "Download %s" : "下載 %s",
    "Upload files to %s" : "上傳檔案到 %s",
    "Note" : "筆記",
    "Select or drop files" : "選擇或拖曳檔案至此",
    "Uploading files" : "檔案上傳中",
    "Uploaded files:" : "已上傳的檔案：",
    "By uploading files, you agree to the %1$sterms of service%2$s." : "上傳檔案即表示您同意 %1$s服務條款%2$s。 ",
    "Name, email, or federated cloud ID …" : "名字，電郵地址或 federated cloud ID …"
},
"nplurals=1; plural=0;");

==> nextcloud-22.0.0-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_sharing/l10n/zh_HK.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with you" : "與您分享",
    "Nothing shared with you yet" : "目前沒有任何與您分享的內容",
    "Files and folders others share with you will show up here" : "與您分享的檔案與資料夾將會顯示在這裡",
    "Shared with others" : "與其他人分享",
    "Nothing shared yet" : "目前沒有分享內容",
    "Files and folders you share will show up here" : "您分享的檔案與資料夾將會顯示在這裡",
    "Shared by link" : "由連結分享",
    "No shared links" : "沒有已分享的連結",
    "Files and folders you share by link will show up here" : "您分享的檔案與資料夾連結將會顯示在這裡",
    "Deleted shares" : "移除分享",
    "No deleted shares" : "沒有移除的分享",
    "Shares you deleted will show up here" : "您刪除的分享會在此顯示",
    "Pending shares" : "等待分享",
    "No pending shares" : "沒有待處理的分享",
    "Shares you have received but not confirmed will show up here" : "您收到但尚未確認的分享將會在此顯示",
    "Shares" : "分享",
    "No shares" : "無分享",
    "Shares will show up here" : "分享將會在此顯示",
    "Restore" : "回復",
    "Restore share" : "還原分享",
    "Something happened. Unable to restore the share." : "出了些狀況，無法還原分享。",
    "Accept share" : "接受分享",
    "Something happened. Unable to accept the share." : "好像有東西出錯了。無法接受分享。",
    "Reject share" : "拒絕分享",
    "Something happened. Unable to reject the share." : "好像有東西出錯了。無法拒絕分享。",
    "Waiting…" : "正在等待……",
    "error" : "錯誤",
    "finished" : "已結束",
    "This will stop your current uploads." : "這會終止目前任何的上傳。",
    "Move or copy" : "移動或複製",
    "Download" : "下載",
    "Delete" : "移除",
    "You can upload into this folder" : "你可以上傳內容到此資料夾",
    "Terms of service" : "服務條款",
    "No compatible server found at {remote}" : "沒有在 {remote} 找到相容的伺服器",
    "Invalid server URL" : "無效的伺服器 URL",
    "Failed to add the public link to your Nextcloud" : "無法將公開連結加入您的 Nextcloud",
    "No expiration date set" : "未指定到期日",
    "Shared by" : "分享自",
    "File shares" : "檔案分享",
    "Downloaded via public link" : "透過公用連結下載",
    "Downloaded by {email}" : "{email} 已下載",
    "{file} downloaded via public link" : "{file} 已透過公用連結下載",
    "{email} downloaded {file}" : "{email} 已下載 {file}",
    "Shared with group {group}" : "與群組 {group} 分享",
    "Removed share for group {group}" : "移除與群組 {group} 分享",
    "{actor} shared with group {group}" : "{actor} 分享給群組 {group}",
    "{actor} removed share for group {group}" : "{actor} 移除了與群組 {group} 的分享",
    "Share for group {group} expired" : "群組 {group} 的分享已過期",
    "You shared {file} with group {group}" : "你分享了 {file} 給群組 {group}",
    "You removed group {group} from {file}" : "你將群組 {group} 從 {file} 移除",
    "{actor} shared {file} with group {group}" : "{actor} 分享 {file} 給群組 {group}",
    "{actor} removed group {group} from {file}" : "{actor} 將群組 {group} 從 {file} 移除",
    "Share for file {file} with group {group} expired" : "與群組 {group} 分享的檔案 {file} 已過期",
    "Shared as public link" : "藉由公用連結分享",
    "Removed public link" : "刪除公開連結",
    "Public link expired" : "公開連結已過期",
    "{actor} shared as public link" : "{actor} 透過公開連結分享",
    "{actor} removed public link" : "{actor} 移除公開連結分享",
    "Public link of {actor} expired" : "{actor} 的公開連結過期了",
    "You shared {file} as public link" : "你藉由公用連結分享了 {file}",
    "You removed public link for {file}" : "您刪除了 {file} 的公開分享連結",
    "Public link expired for {file}" : "{file} 的公開連結已過期",
    "{actor} shared {file} as public link" : "{actor} 透過公開連結分享 {file}",
    "{actor} removed public link for {file}" : "{actor} 移除 {file} 的公開連結分享",
    "Public link of {actor} for {file} expired" : "{actor} 公開分享 {file} 的連結過期了",
    "{user} accepted the remote share" : "{user} 接受了遠端分享",
    "{user} declined the remote share" : "{user} 拒絕了遠端分享",
    "You received a new remote share {file} from {user}" : "您收到了一個遠端分享 {file} 來自於 {user}",
    "{user} accepted the remote share of {file}" : "{user} 接受了檔案 {file} 的遠端分享",
    "{user} declined the remote share of {file}" : "{user} 拒絕了檔案 {file} 的遠端分享",
    "{user} unshared {file} from you" : "{user} 取消與你分享檔案 {file}",
    "Shared with {user}" : "與 {user} 分享",
    "Removed share for {user}" : "移除對 {user} 的分享",
    "You removed yourself" : "您自己移除",
    "{actor} removed themselves" : "{actor} 已將自己移除",
    "{actor} shared with {user}" : "{actor} 分享給 {user}",
    "{actor} removed share for {user}" : "{actor} 移除了對 {user} 的分享",
    "Shared by {actor}" : "由 {actor} 分享",
    "{actor} removed share" : "{actor} 移除了分享",
    "Share for {user} expired" : "{user} 的分享已過期",
    "Share expired" : "分享已過期",
    "You shared {file} with {user}" : "你與 {user} 分享了 {file}",
    "You removed {user} from {file}" : "你將 {user} 從 {file} 移除",
    "You removed yourself from {file}" : "您已將自己從 {file} 移除",
    "{actor} removed themselves from {file}" : "{actor} 從 {file} 移除了自己",
    "{actor} shared {file} with {user}" : "{actor} 分享了 {file} 給 {user}",
    "{actor} removed {user} from {file}" : "{actor} 移除 {user} 從 {file}",
    "{actor} shared {file} with you" : "{actor} 與你分享了 {file}",
    "{actor} removed you from the share named {file}" : "{actor} 將您從名為 {file} 的分享中移除了",
    "Share for file {file} with {user} expired" : "與 {user} 分享的檔案 {file} 已過期",
    "Share for file {file} expired" : "檔案 {file} 的分享已過期",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "email或公開連結分享的檔案與資料夾已被 <strong>下載</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "檔案或目錄已被 <strong>其他伺服器</strong> 分享",
    "Files" : "檔案",
    "A file or folder has been <strong>shared</strong>" : "檔案或目錄已被 <strong>分享</strong>",
    "Shared link" : "已分享的連結",
    "Wrong share ID, share doesn't exist" : "錯誤的分享 ID ，分享不存在",
    "Could not delete share" : "無法刪除分享",
    "Please specify a file or folder path" : "請指定檔案或資料夾路徑",
    "Wrong path, file/folder doesn't exist" : "錯誤的路徑，該檔案或資料夾不存在",
    "Could not create share" : "無法建立分享",
    "Invalid permissions" : "無效的權限",
    "Please specify a valid user" : "請選擇一個有效的用戶",
    "Group sharing is disabled by the administrator" : "群組分享已被管理員停用",
    "Please specify a valid group" : "請指定一個有效的群組",
    "Public link sharing is disabled by the administrator" : "公開連結分享已被管理員停用",
    "Public upload disabled by the administrator" : "公開上傳已被管理員停用",
    "Public upload is only possible for publicly shared folders" : "只有公開分享的資料夾可以接受公開上傳",
    "Sharing %s sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "因為未啟用 Nextcloud Talk，因此透過 Nextcloud Talk 傳送密碼分享 %s 失敗",
    "Invalid date, date format must be YYYY-MM-DD" : "無效的日期，需為 YYYY-MM-DD 格式",
    "Sharing %1$s failed because the back end does not allow shares from type %2$s" : "分享 %1$s 失敗，因為後端不允許來自 %2$s 類型的分享",
    "Please specify a valid federated user ID" : "請指定一個有效的聯合用戶 ID",
    "Please specify a valid federated group ID" : "請指定一個有效的聯合群組 ID",
    "You cannot share to a Circle if the app is not enabled" : "當應用未被啟用，你無法分享到circle。",
    "Please specify a valid circle" : "請指定一個有效的circle",
    "Sharing %s failed because the back end does not support room shares" : "分享 %s 失敗，因為後端不支援聊天室分享",
    "Unknown share type" : "未知的分享類型",
    "Not a directory" : "這不是一個資料夾",
    "Could not lock node" : "無法鎖定節點",
    "Could not lock path" : "無法鎖定路徑",
    "Wrong or no update parameter given" : "更新參數不正確或未提供",
    "Cannot change permissions for public share links" : "無法由公開分享的連結變更權限",
    "Sharing sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "因為未啟用 Nextcloud Talk，因此透過 Nextcloud Talk 傳送密碼分享失敗",
    "shared by %s" : "分享自 %s",
    "Download all files" : "下載所有檔案",
    "Direct link" : "直接連結",
    "Add to your %s" : "新增至您的 %s",
    "Share API is disabled" : "分享 API 已停用",
    "File sharing" : "檔案分享",
    "Share will expire tomorrow" : "分享將於明日到期",
    "One or more of your shares will expire tomorrow" : "您的一個或多個分享將於明日到期",
    "Your share of {node} will expire tomorrow" : "您 {node} 的分享將於明日到期",
    "You received {share} as a share by {user}" : "您收到 {user} 的分享 {share}",
    "You received {share} to group {group} as a share by {user}" : "您收到了 {user} 分享的 {share} 到 {group} 群組",
    "Accept" : "接受",
    "Reject" : "拒絕",
    "This application enables users to share files within Nextcloud. If enabled, the admin can choose which groups can share files. The applicable users can then share files and folders with other users and groups within Nextcloud. In addition, if the admin enables the share link feature, an external link can be used to share files with other users outside of Nextcloud. Admins can also enforce passwords, expirations dates, and enable server to server sharing via share links, as well as sharing from mobile devices.\nTurning the feature off removes shared files and folders on the server for all share recipients, and also on the sync clients and mobile apps. More information is available in the Nextcloud Documentation." : "該應用程序使用戶可以在Nextcloud中共享檔案。如果啟用，管理員可以選擇可以共享文件的群組。然後，適用的用戶可以與Nextcloud中的其他用戶和群組共享檔案和資料夾。此外，如果管理員啟用了共享連結功能，則可以使用外部連結與Nextcloud之外的其他用戶分享檔案。管理員還可以實施密碼，有效期，並允許通過分享檔案進行伺服器到伺服器的分享以及從流動裝置進行分享。\n關閉此功能將刪除伺服器上所有分享收件人以及同步客戶端和流動應用程序上的分享了檔案和資料夾。Nextcloud文檔中提供了更多信息。",
    "Sharing" : "分享",
    "Accept user and group shares by default" : "默認接受用戶和群組共享",
    "Allow editing" : "允許編輯",
    "Allow creating" : "允許創建",
    "Allow deleting" : "允許刪除",
    "Allow resharing" : "允許轉貼分享",
    "Expiration date enforced" : "已設定到期日",
    "Set expiration date" : "設定到期日",
    "Enter a date" : "輸入日期",
    "Note to recipient" : "給接收者的訊息",
    "Unshare" : "撤回分享",
    "group" : "群組",
    "conversation" : "對話",
    "remote" : "遠端",
    "remote group" : "遠端群組",
    "guest" : "訪客",
    "Shared with the group {user} by {owner}" : "由 {owner} 分享予群組 {user}",
    "Shared with the conversation {user} by {owner}" : "{owner}與{user}共享",
    "Shared with {user} by {owner}" : "{user}與{owner}共享",
    "Added by {initiator}" : "由{initiator}添加",
    "Via “{folder}”" : "透過 “{folder}”",
    "Internal link" : "內部連結",
    "Link copied" : "連結已複製",
    "Cannot copy, please copy the link manually" : "無法複製，請手動複製連結",
    "Copy to clipboard" : "複製到剪貼板",
    "Only works for users with access to this folder" : "只對可以存取此資料夾的用戶生效",
    "Only works for users with access to this file" : "僅適用於有權存取此檔案的用戶",
    "Please enter the following required information before creating the share" : "創建分享之前，請輸入以下必填信息",
    "Password protection (enforced)" : "密碼保護（強制）",
    "Password protection" : "密碼保護",
    "Enter a password" : "輸入密碼",
    "Expiration date (enforced)" : "屆滿日期（強制）",
    "Create share" : "創建分享",
    "Cancel" : "取消",
    "Share label" : "分享標籤",
    "Read only" : "唯讀",
    "Allow upload and editing" : "允許上傳及編輯",
    "File drop (upload only)" : "拖曳檔案(僅供上傳)",
    "Hide download" : "隱藏下載",
    "Password protect" : "密碼防護",
    "Video verification" : "視頻驗證",
    "Enter a note for the share recipient" : "輸入分享收件人的註釋",
    "Add another link" : "加入另一個連結",
    "Create a new share link" : "建立新分享連結",
    "{shareWith} by {initiator}" : "{initiator} 分享了 {shareWith}",
    "Shared via link by {initiator}" : "由 {initiator} 透過連結分享",
    "Mail share ({label})" : "分享郵件（{label}）",
    "Share link ({label})" : "分享連結（{label})",
    "Share link" : "分享連結",
    "Error, please enter proper password and/or expiration date" : "錯誤，請輸入正確的密碼和/或有效期",
    "No recommendations. Start typing." : "沒有建議。開始輸入。",
    "Resharing is not allowed" : "不允許重新分享",
    "Name or email …" : "名字或電郵地址",
    "Name, email, or Federated Cloud ID …" : "名字，電郵地址或 Federated Cloud ID …",
    "Searching …" : "搜尋中 …",
    "No elements found." : "找不到元素。",
    "Search globally" : "全域搜尋",
    "on {server}" : "在 {server} 上",
    "Others with access" : "其他擁有存取權限的人",
    "No other users with access found" : "找不到其他擁有存取權限的用戶",
    "Toggle list of others with access to this directory" : "切換有權存取此目錄的其他人的清單",
    "Toggle list of others with access to this file" : "切換有權存取此檔案的其他人的清單",
    "Unable to fetch inherited shares" : "無法獲取繼承的分享",
    "Unable to load the shares list" : "無法載入分享清單",
    "Expires {relativetime}" : "有效期至 {relativetime}",
    "this share just expired." : "此分享剛過期。",
    "Link to a file" : "連結到一個檔案",
    "Error creating the share: {errorMessage}" : "創建分享出錯：{errorMessage}",
    "Error creating the share" : "創建分享出錯",
    "Error updating the share: {errorMessage}" : "更新分享出錯：{errorMessage}",
    "Error updating the share" : "更新分享出錯",
    "Shared" : "已分享",
    "Share" : "分享",
    "Shared with" : "分享給",
    "Shared with you and the group {group} by {owner}" : "由 {owner} 分享給您和 {group}群組",
    "Shared with you and {circle} by {owner}" : "{owner} 分享給您和 {circle}",
    "Shared with you and the conversation {conversation} by {owner}" : "{owner} 分享給您和 {conversation} 對話",
    "Shared with you in a conversation by {owner}" : "{owner} 在對話中分享給您",
    "Shared with you by {owner}" : "{owner} 已經和您分享",
    "No entries found in this folder" : "在此資料夾中沒有任何項目",
    "Name" : "名稱",
    "Share time" : "分享時間",
    "Expiration date" : "到期日",
    "Sorry, this link doesn’t seem to work anymore." : "抱歉，此連結已經失效",
    "Reasons might be:" : "可能的原因：",
    "the item was removed" : "項目已經移除",
    "the link expired" : "連結已過期",
    "sharing is disabled" : "分享功能已停用",
    "For more info, please ask the person who sent this link." : "請詢問告訴您此連結的人以瞭解更多",
    "Share note" : "分享筆記",
    "Toggle grid view" : "切換網格檢視",
    "Download %s" : "下載 %s",
    "Upload files to %s" : "上傳檔案到 %s",
    "Note" : "筆記",
    "Select or drop files" : "選擇或拖曳檔案至此",
    "Uploading files" : "檔案上傳中",
    "Uploaded files:" : "已上傳的檔案：",
    "By uploading files, you agree to the %1$sterms of service%2$s." : "上傳檔案即表示您同意 %1$s服務條款%2$s。 ",
    "Add to your Nextcloud" : "加入到您的 Nextcloud",
    "invalid permissions" : "無效的權限",
    "Can't change permissions for public share links" : "無法由公開分享的連結變更權限",
    "Name, email, or federated cloud ID …" : "名字，電郵地址或 federated cloud ID …"
},
"nplurals=1; plural=0;");
